# Marsys Individual Contributor License Agreement

Thank you for your interest in contributing to the Marsys Multi-Agent Coordination Framework ("the Project").

**Project Owner:** Marsys Project
**Copyright Holder:** rezaho
**Contact:** reza@marsys.ai

This Contributor License Agreement ("Agreement") documents the rights granted by contributors to the Project Owner and clarifies copyright ownership.

---

## Important: Copyright Ownership

**By signing this Agreement, you acknowledge and agree that:**

1. **No Copyright Transfer:** Your contribution does NOT transfer copyright ownership to you. The Project Owner retains sole copyright ownership of the Marsys codebase.

2. **License Grant Only:** You grant a copyright and patent license (as detailed below) but you do NOT become a copyright holder through your contribution.

3. **Original Author Rights:** The original author retains the exclusive right to:
   - Relicense the project
   - Transfer copyright if needed for the project's sustainability
   - Offer commercial or alternative licenses
   - Make all ownership and licensing decisions

4. **Successors and Assigns:** All rights granted under this Agreement may be assigned to successors and assigns of the copyright holder, including to a corporate entity, without requiring additional consent from you.

---

## Terms and Conditions

### 1. Definitions

**"You"** (or **"Your"**) means the copyright owner or legal entity authorized by the copyright owner that is exercising rights under this Agreement.

**"Contribution"** means any original work of authorship, including any modifications or additions to an existing work, that is intentionally submitted by You for inclusion in, or documentation of, the Project.

**"Submitted"** means any form of electronic, verbal, or written communication sent to the Project Owner or their representatives, including but not limited to communication on electronic mailing lists, source code control systems, and issue tracking systems.

---

### 2. Grant of Copyright License

Subject to the terms and conditions of this Agreement, You hereby grant to the **Marsys Project copyright holder, their successors, and assigns,** and to recipients of software distributed by the Project Owner:

A perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable copyright license to:

- Reproduce Your Contributions
- Prepare derivative works of Your Contributions
- Publicly display and publicly perform Your Contributions
- **Sublicense Your Contributions** (including to commercial and proprietary licensees)
- Distribute Your Contributions and derivative works in Source or Object form

This license allows the Project Owner to include Your Contributions in both open-source and commercial/proprietary versions of the Project.

---

### 3. Grant of Patent License

Subject to the terms and conditions of this Agreement, You hereby grant to the **Marsys Project copyright holder, their successors, and assigns,** and to recipients of software distributed by the Project Owner:

A perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable (except as stated in this section) patent license to:

- Make, have made, use, offer to sell, sell, import, and otherwise transfer Your Contributions

This license applies only to those patent claims licensable by You that are necessarily infringed by Your Contribution(s) alone or by combination of Your Contribution(s) with the Project.

If You or any entity You represent institutes patent litigation against any entity (including a cross-claim or counterclaim in a lawsuit) alleging that the Project or a Contribution incorporated within the Project constitutes direct or contributory patent infringement, then any patent licenses granted to You under this Agreement for that Project shall terminate as of the date such litigation is filed.

---

### 4. You Retain Authorship Credit

You will be credited in the AUTHORS file for your contribution. This credit does NOT constitute copyright ownership. You retain the right to use Your Contributions for any purpose.

---

### 5. Employer Rights and Representations

You represent that:

a) You are legally entitled to grant the above licenses.

b) If Your employer(s) has rights to intellectual property that You create that includes Your Contributions, You represent that:
   - You have received permission to make Contributions on behalf of that employer, OR
   - Your employer has waived such rights for Your Contributions to the Project, OR
   - Your employer has executed a separate Corporate Contributor License Agreement with the Project Owner.

---

### 6. Original Work

You represent that:

a) Each of Your Contributions is Your original creation (see Section 8 for submissions on behalf of others).

b) Your Contribution submissions include complete details of any third-party license or other restriction (including, but not limited to, related patents and trademarks) of which You are personally aware and which are associated with any part of Your Contributions.

---

### 7. No Support Obligation

You are not expected to provide support for Your Contributions, except to the extent You desire to provide support. You may provide support for free, for a fee, or not at all.

---

### 8. Third-Party Submissions

Should You wish to submit work that is not Your original creation, You may submit it to the Project Owner separately from any Contribution, identifying the complete details of its source and of any license or other restriction (including, but not limited to, related patents, trademarks, and license agreements) of which You are personally aware, and conspicuously marking the work as:

**"Submitted on behalf of a third-party: [named here]"**

---

### 9. Notification of Changes

You agree to notify the Project Owner of any facts or circumstances of which You become aware that would make these representations inaccurate in any respect.

---

### 10. No Warranty

Unless required by applicable law or agreed to in writing, You provide Your Contributions on an **"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND**, either express or implied, including, without limitation, any warranties or conditions of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A PARTICULAR PURPOSE.

---

## How to Sign This Agreement

This CLA is signed electronically via CLA Assistant when you submit your first pull request to the Marsys repository.

**By clicking "I Agree" via CLA Assistant, you accept this Agreement, including the acknowledgment that:**
- You do NOT acquire copyright ownership through your contribution
- The original author retains sole copyright ownership
- All rights granted may be assigned to successors and assigns (including corporate entities)

---

## Questions?

For questions about this Contributor License Agreement:

**Email:** reza@marsys.ai
**GitHub:** @rezaho

For more information, see:
- [COPYRIGHT](COPYRIGHT) - Copyright ownership details
- [CONTRIBUTING.md](CONTRIBUTING.md) - Contribution guidelines
- [LICENSE](LICENSE) - Apache License 2.0 full text
